==> Pyrogram-0.6.5-py3-none-any.whl: pyrogram/api/types/channel_admin_log_event_action_change_photo.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class ChannelAdminLogEventActionChangePhoto(Object):
    """
    Attributes:
        ID (:obj:`int`): ``0xb82f55c3``

    Args:
        prev_photo: :class:`pyrogram.api.types.ChatPhoto`
        new_photo: :class:`pyrogram.api.types.ChatPhoto`
    """
    ID = 0xb82f55c3

    def __init__(self, prev_photo, new_photo):
        self.prev_photo = prev_photo  # ChatPhoto
        self.new_photo = new_photo  # ChatPhoto

    @staticmethod
    def read(b: BytesIO, *args) -> "ChannelAdminLogEventActionChangePhoto":
        # No flags
        
        prev_photo = Object.read(b)
        
        new_photo = Object.read(b)
        
        return ChannelAdminLogEventActionChangePhoto(prev_photo, new_photo)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.prev_photo.write())
        
        b.write(self.new_photo.write())
        
        return b.getvalue()

==> Pyrogram-0.7.1-py3-none-any.whl: pyrogram/api/types/channel_admin_log_event_action_change_photo.py <==
# Pyrogram - Telegram MTProto API Client Library for Python
# Copyright (C) 2017-2018 Dan Tès <https://github.com/delivrance>
#
# This file is part of Pyrogram.
#
# Pyrogram is free software: you can redistribute it and/or modify
# it under the terms of the GNU Lesser General Public License as published
# by the Free Software Foundation, either version 3 of the License, or
# (at your option) any later version.
#
# Pyrogram is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU Lesser General Public License for more details.
#
# You should have received a copy of the GNU Lesser General Public License
# along with Pyrogram.  If not, see <http://www.gnu.org/licenses/>.

from io import BytesIO

from pyrogram.api.core import *


class ChannelAdminLogEventActionChangePhoto(Object):
    """Attributes:
        ID: ``0xb82f55c3``

    Args:
        prev_photo: Either :obj:`ChatPhotoEmpty <pyrogram.api.types.ChatPhotoEmpty>` or :obj:`ChatPhoto <pyrogram.api.types.ChatPhoto>`
        new_photo: Either :obj:`ChatPhotoEmpty <pyrogram.api.types.ChatPhotoEmpty>` or :obj:`ChatPhoto <pyrogram.api.types.ChatPhoto>`
    """
    ID = 0xb82f55c3

    def __init__(self, prev_photo, new_photo):
        self.prev_photo = prev_photo  # ChatPhoto
        self.new_photo = new_photo  # ChatPhoto

    @staticmethod
    def read(b: BytesIO, *args) -> "ChannelAdminLogEventActionChangePhoto":
        # No flags
        
        prev_photo = Object.read(b)
        
        new_photo = Object.read(b)
        
        return ChannelAdminLogEventActionChangePhoto(prev_photo, new_photo)

    def write(self) -> bytes:
        b = BytesIO()
        b.write(Int(self.ID, False))

        # No flags
        
        b.write(self.prev_photo.write())
        
        b.write(self.new_photo.write())
        
        return b.getvalue()
